package sql

import (
	"testing"

	"xbus.io/xbus/storage"
	"xbus.io/xbus/testutils"
	"xbus.io/xbus/testutils/sqldb"
	storagetest "xbus.io/xbus/testutils/storage"
)

func makeSessionStorageFactory(tb testing.TB) (
	func(tb testing.TB) (storage.SessionStorage, func()),
	func(),
) {
	testDB := sqldb.GetTestDB(tb)
	if testDB == nil {
		tb.Fatal("Could not get a test db")
	}
	_, db := testDB.GetModelDB(1)

	return func(tb testing.TB) (storage.SessionStorage, func()) {
			return NewSessionStorage(db, testutils.GetTestLogger(tb)), func() {
				if _, err := db.Engine.DB().Exec("DELETE FROM account_session"); err != nil {
					tb.Fatal(err)
				}
			}
		}, func() {
			db.Close()
			testDB.Close()
		}
}

func TestSessionStorage(t *testing.T) {
	factory, clean := makeSessionStorageFactory(t)
	defer clean()

	storagetest.SessionStorageTests(t, factory)
}
